==> kudu-client-1.4.0-sources.jar: org/apache/kudu/client/ScannerExpiredException.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.kudu.client;

import org.apache.kudu.annotations.InterfaceAudience;
import org.apache.kudu.annotations.InterfaceStability;

/**
 * A scanner expired exception.
 */
@InterfaceAudience.Private
@InterfaceStability.Evolving
@SuppressWarnings("serial")
class ScannerExpiredException extends RecoverableException {
  /**
   * Constructor.
   * @param status status object containing the reason for the exception
   * trace
   */
  ScannerExpiredException(Status status) {
    super(status);
  }

  /**
   * Constructor.
   * @param status status object containing the reason for the exception
   * @param cause the exception that caused this one to be thrown
   */
  ScannerExpiredException(Status status, Throwable cause) {
    super(status, cause);
  }
}

==> kudu-client-1.5.0-sources.jar: org/apache/kudu/client/ScannerExpiredException.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.kudu.client;

import org.apache.yetus.audience.InterfaceAudience;
import org.apache.yetus.audience.InterfaceStability;

/**
 * A scanner expired exception.
 */
@InterfaceAudience.Private
@InterfaceStability.Evolving
@SuppressWarnings("serial")
class ScannerExpiredException extends RecoverableException {
  /**
   * Constructor.
   * @param status status object containing the reason for the exception
   * trace
   */
  ScannerExpiredException(Status status) {
    super(status);
  }

  /**
   * Constructor.
   * @param status status object containing the reason for the exception
   * @param cause the exception that caused this one to be thrown
   */
  ScannerExpiredException(Status status, Throwable cause) {
    super(status, cause);
  }
}
